==> dde-calendar_5.9.5.orig.tar.xz: dde-calendar-5.9.5/translations/dde-calendar-service_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Työ</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Oma</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Päivä ennen alkua</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Muistuta huomenna</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Muistuta myöhemmin</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 min myöhemmin</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 tunnin kuluttua</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 tunnin kuluttua</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Huomenna</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Ajasta muistutus</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
</context>
<context>
    <name>JobRemindManager</name>
    <message>
        <source>One day before start</source>
        <translation type="vanished">Yksi päivä ennen alkua</translation>
    </message>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation type="vanished">Sulje</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation type="vanished">Muistuta huomenna</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation type="vanished">Muistuta myöhemmin</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation type="vanished">Ajasta muistutus</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation type="vanished">%1 - %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation type="vanished">Tänään</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation type="vanished">Huomenna</translation>
    </message>
</context>
</TS>

==> dde-calendar_5.9.14.orig.tar.xz: dde-calendar-5.9.14/translations/dde-calendar-service_fi.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="fi">
<context>
    <name>DAccountDataBase</name>
    <message>
        <source>Work</source>
        <translation>Työ</translation>
    </message>
    <message>
        <source>Life</source>
        <translation>Oma</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
</context>
<context>
    <name>DAlarmManager</name>
    <message>
        <source>Close</source>
        <comment>button</comment>
        <translation>Sulje</translation>
    </message>
    <message>
        <source>One day before start</source>
        <translation>Päivä ennen alkua</translation>
    </message>
    <message>
        <source>Remind me tomorrow</source>
        <translation>Muistuta huomenna</translation>
    </message>
    <message>
        <source>Remind me later</source>
        <translation>Muistuta myöhemmin</translation>
    </message>
    <message>
        <source>15 mins later</source>
        <translation>15 min myöhemmin</translation>
    </message>
    <message>
        <source>1 hour later</source>
        <translation>1 tunnin kuluttua</translation>
    </message>
    <message>
        <source>4 hours later</source>
        <translation>4 tunnin kuluttua</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Huomenna</translation>
    </message>
    <message>
        <source>Schedule Reminder</source>
        <translation>Ajasta muistutus</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 - %2</translation>
    </message>
    <message>
        <source>Today</source>
        <translation>Tänään</translation>
    </message>
</context>
<context>
    <name>Return</name>
    <message>
        <source>Today</source>
        <comment>Return</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Return Today</name>
    <message>
        <source>Today</source>
        <comment>Return Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>today</name>
    <message>
        <source>Today</source>
        <comment>Today</comment>
        <translation type="unfinished"/>
    </message>
</context>
</TS>
